/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var vscode = require("vscode");
var path = require("path");
function isMarkdownFile(document) {
    return document.languageId === 'markdown'
        && document.uri.scheme !== 'markdown'; // prevent processing of own documents
}
exports.isMarkdownFile = isMarkdownFile;
function getMarkdownUri(uri) {
    return uri.with({ scheme: 'markdown', path: uri.path + '.rendered', query: uri.toString() });
}
exports.getMarkdownUri = getMarkdownUri;
var MDDocumentContentProvider = (function () {
    function MDDocumentContentProvider(engine, context) {
        this.engine = engine;
        this.context = context;
        this._onDidChange = new vscode.EventEmitter();
        this._waiting = false;
    }
    MDDocumentContentProvider.prototype.getMediaPath = function (mediaFile) {
        return vscode.Uri.file(this.context.asAbsolutePath(path.join('media', mediaFile))).toString();
    };
    MDDocumentContentProvider.prototype.isAbsolute = function (p) {
        return path.normalize(p + '/') === path.normalize(path.resolve(p) + '/');
    };
    MDDocumentContentProvider.prototype.fixHref = function (resource, href) {
        if (!href) {
            return href;
        }
        // Use href if it is already an URL
        if (vscode.Uri.parse(href).scheme) {
            return href;
        }
        // Use href as file URI if it is absolute
        if (this.isAbsolute(href)) {
            return vscode.Uri.file(href).toString();
        }
        // use a workspace relative path if there is a workspace
        var rootPath = vscode.workspace.rootPath;
        if (rootPath) {
            return vscode.Uri.file(path.join(rootPath, href)).toString();
        }
        // otherwise look relative to the markdown file
        return vscode.Uri.file(path.join(path.dirname(resource.fsPath), href)).toString();
    };
    MDDocumentContentProvider.prototype.computeCustomStyleSheetIncludes = function (uri) {
        var _this = this;
        var styles = vscode.workspace.getConfiguration('markdown')['styles'];
        if (styles && Array.isArray(styles) && styles.length > 0) {
            return styles.map(function (style) {
                return "<link rel=\"stylesheet\" href=\"" + _this.fixHref(uri, style) + "\" type=\"text/css\" media=\"screen\">";
            }).join('\n');
        }
        return '';
    };
    MDDocumentContentProvider.prototype.getSettingsOverrideStyles = function () {
        var previewSettings = vscode.workspace.getConfiguration('markdown')['preview'];
        if (!previewSettings) {
            return '';
        }
        var fontFamily = previewSettings.fontFamily, fontSize = previewSettings.fontSize, lineHeight = previewSettings.lineHeight;
        return "<style>\n\t\t\tbody {\n\t\t\t\t" + (fontFamily ? "font-family: " + fontFamily + ";" : '') + "\n\t\t\t\t" + (+fontSize > 0 ? "font-size: " + fontSize + "px;" : '') + "\n\t\t\t\t" + (+lineHeight > 0 ? "line-height: " + lineHeight + ";" : '') + "\n\t\t\t}\n\t\t</style>";
    };
    MDDocumentContentProvider.prototype.provideTextDocumentContent = function (uri) {
        var _this = this;
        var sourceUri = vscode.Uri.parse(uri.query);
        return vscode.workspace.openTextDocument(sourceUri).then(function (document) {
            var scrollBeyondLastLine = vscode.workspace.getConfiguration('editor')['scrollBeyondLastLine'];
            var wordWrap = vscode.workspace.getConfiguration('editor')['wordWrap'];
            var markdownConfig = vscode.workspace.getConfiguration('markdown');
            var previewFrontMatter = markdownConfig.get('previewFrontMatter', 'hide');
            var initialLine = 0;
            var editor = vscode.window.activeTextEditor;
            if (editor && editor.document.uri.path === sourceUri.path) {
                initialLine = editor.selection.active.line;
            }
            var body = _this.engine.render(sourceUri, previewFrontMatter === 'hide', document.getText());
            return "<!DOCTYPE html>\n\t\t\t\t<html>\n\t\t\t\t<head>\n\t\t\t\t\t<meta http-equiv=\"Content-type\" content=\"text/html;charset=UTF-8\">\n\t\t\t\t\t<link rel=\"stylesheet\" type=\"text/css\" href=\"" + _this.getMediaPath('markdown.css') + "\">\n\t\t\t\t\t<link rel=\"stylesheet\" type=\"text/css\" href=\"" + _this.getMediaPath('tomorrow.css') + "\">\n\t\t\t\t\t" + _this.getSettingsOverrideStyles() + "\n\t\t\t\t\t" + _this.computeCustomStyleSheetIncludes(uri) + "\n\t\t\t\t\t<base href=\"" + document.uri.toString(true) + "\">\n\t\t\t\t\t<script>\n\t\t\t\t\t\twindow.initialData = {\n\t\t\t\t\t\t\tsource: \"" + encodeURIComponent(sourceUri.toString(true)) + "\",\n\t\t\t\t\t\t\tline: " + initialLine + ",\n\t\t\t\t\t\t\tscrollPreviewWithEditorSelection: " + !!markdownConfig.get('preview.scrollPreviewWithEditorSelection', true) + ",\n\t\t\t\t\t\t\tscrollEditorWithPreview: " + !!markdownConfig.get('preview.scrollEditorWithPreview', true) + ",\n\t\t\t\t\t\t\tdoubleClickToSwitchToEditor: " + !!markdownConfig.get('preview.doubleClickToSwitchToEditor', true) + ",\n\t\t\t\t\t\t};\n\t\t\t\t\t</script>\n\t\t\t\t</head>\n\t\t\t\t<body class=\"" + (scrollBeyondLastLine ? 'scrollBeyondLastLine' : '') + " " + (wordWrap ? 'wordWrap' : '') + " " + (!!markdownConfig.get('preview.markEditorSelection') ? 'showEditorSelection' : '') + "\">\n\t\t\t\t\t" + body + "\n\t\t\t\t\t<script src=\"" + _this.getMediaPath('main.js') + "\"></script>\n\t\t\t\t</body>\n\t\t\t\t</html>";
        });
    };
    Object.defineProperty(MDDocumentContentProvider.prototype, "onDidChange", {
        get: function () {
            return this._onDidChange.event;
        },
        enumerable: true,
        configurable: true
    });
    MDDocumentContentProvider.prototype.update = function (uri) {
        var _this = this;
        if (!this._waiting) {
            this._waiting = true;
            setTimeout(function () {
                _this._waiting = false;
                _this._onDidChange.fire(uri);
            }, 300);
        }
    };
    return MDDocumentContentProvider;
}());
exports.MDDocumentContentProvider = MDDocumentContentProvider;

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/49129d126e2c3c5592cfc8a509d872067b69d262/extensions/markdown/out/previewContentProvider.js.map
